# Core

Core configuration, task definition, result types, and exceptions.

## Configuration

### ModelProvider

::: rotalabs_eval.core.config.ModelProvider
    options:
      show_source: true

### ModelConfig

::: rotalabs_eval.core.config.ModelConfig
    options:
      show_source: true

### MetricConfig

::: rotalabs_eval.core.config.MetricConfig
    options:
      show_source: true

### StatisticsConfig

::: rotalabs_eval.core.config.StatisticsConfig
    options:
      show_source: true

### InferenceConfig

::: rotalabs_eval.core.config.InferenceConfig
    options:
      show_source: true

### SamplingConfig

::: rotalabs_eval.core.config.SamplingConfig
    options:
      show_source: true

## Task

### EvalTask

::: rotalabs_eval.core.task.EvalTask
    options:
      show_source: true

## Results

### MetricValue

::: rotalabs_eval.core.result.MetricValue
    options:
      show_source: true

### CostBreakdown

::: rotalabs_eval.core.result.CostBreakdown
    options:
      show_source: true

### LatencyStats

::: rotalabs_eval.core.result.LatencyStats
    options:
      show_source: true

### EvalResult

::: rotalabs_eval.core.result.EvalResult
    options:
      show_source: true

### ComparisonResult

::: rotalabs_eval.core.result.ComparisonResult
    options:
      show_source: true

## Types

### ModelResponse

::: rotalabs_eval.core.types.ModelResponse
    options:
      show_source: true

## Exceptions

### RotalabsEvalError

::: rotalabs_eval.core.exceptions.RotalabsEvalError
    options:
      show_source: true

### EvalConfigError

::: rotalabs_eval.core.exceptions.EvalConfigError
    options:
      show_source: true

### EvalInferenceError

::: rotalabs_eval.core.exceptions.EvalInferenceError
    options:
      show_source: true

### EvalRateLimitError

::: rotalabs_eval.core.exceptions.EvalRateLimitError
    options:
      show_source: true

### EvalMetricError

::: rotalabs_eval.core.exceptions.EvalMetricError
    options:
      show_source: true

### EvalCacheError

::: rotalabs_eval.core.exceptions.EvalCacheError
    options:
      show_source: true
